# eric7.Project.UserProjectFile

Module implementing a class representing the user project JSON file.

### Global Attributes

Project

### Classes

UserProjectFile | Class representing the user project JSON file.

### Functions

None

## UserProjectFile

Class representing the user project JSON file.

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

UserProjectFile | Constructor
readFile | Public method to read the user project data from a user project JSON file.
writeFile | Public method to write the user project data to a user project JSON file.

### Static Methods

None

#### UserProjectFile (Constructor)

UserProjectFile(project: Project, parent: QObject = None)

Constructor

project (Project)
  reference to the project object
parent (QObject (optional))
  reference to the parent object (defaults to None)

#### UserProjectFile.readFile

readFile(filename: str)

Public method to read the user project data from a user project JSON file.

filename (str)
  name of the project file

Return:
  flag indicating a successful read

Return Type:
  bool

#### UserProjectFile.writeFile

writeFile(filename: str)

Public method to write the user project data to a user project JSON file.

filename (str)
  name of the user project file

Return:
  flag indicating a successful write

Return Type:
  bool

Up